# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from verity471.models.activity_location import ActivityLocation
from verity471.models.breach_alert_by_id_response import BreachAlertByIdResponse
from verity471.models.breach_alerts_response_stream import BreachAlertsResponseStream
from verity471.models.exploit_status import ExploitStatus
from verity471.models.fintel_reports_response_stream import FintelReportsResponseStream
from verity471.models.fintel_response import FintelResponse
from verity471.models.geopol_report_details_response import GeopolReportDetailsResponse
from verity471.models.geopol_reports_response_stream import GeopolReportsResponseStream
from verity471.models.info_report_response import InfoReportResponse
from verity471.models.info_reports_response_stream import InfoReportsResponseStream
from verity471.models.interest_level import InterestLevel
from verity471.models.malware_report_response import MalwareReportResponse
from verity471.models.malware_reports_response_stream import MalwareReportsResponseStream
from verity471.models.patch_status import PatchStatus
from verity471.models.report_response_stream import ReportResponseStream
from verity471.models.risk_level import RiskLevel
from verity471.models.spot_report_response import SpotReportResponse
from verity471.models.spot_reports_response_stream import SpotReportsResponseStream
from verity471.models.vulnerabilities_report_details_response import VulnerabilitiesReportDetailsResponse
from verity471.models.vulnerabilities_reports_response_stream import VulnerabilitiesReportsResponseStream
from verity471.models.vulnerability_status import VulnerabilityStatus

from verity471.api_client import ApiClient, RequestSerialized
from verity471.api_response import ApiResponse
from verity471.rest import RESTResponseType


class ReportsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_reports_breach_alert_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BreachAlertByIdResponse:
        """Get a breach alert report details


        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertByIdResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_breach_alert_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BreachAlertByIdResponse]:
        """Get a breach alert report details


        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertByIdResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_breach_alert_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a breach alert report details


        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertByIdResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_breach_alert_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/breach-alert/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_breach_alert_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BreachAlertsResponseStream:
        """Get all breach alert reports (stream)

        Returns list of reports

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_breach_alert_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BreachAlertsResponseStream]:
        """Get all breach alert reports (stream)

        Returns list of reports

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_breach_alert_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all breach alert reports (stream)

        Returns list of reports

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_breach_alert_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BreachAlertsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_breach_alert_stream_serialize(
        self,
        text_filter,
        girs,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/breach-alert/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_fintel_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FintelResponse:
        """Get a fintel report details

        Returns a fintel report based on id

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_fintel_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FintelResponse]:
        """Get a fintel report details

        Returns a fintel report based on id

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_fintel_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a fintel report details

        Returns a fintel report based on id

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_fintel_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/fintel/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_fintel_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> FintelReportsResponseStream:
        """Get all fintel reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param sub_type: If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_fintel_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[FintelReportsResponseStream]:
        """Get all fintel reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param sub_type: If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_fintel_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all fintel reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param sub_type: If using filter `type=fintel`, you can then further filter result by subtypes (supports multiple). Allowed values: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_fintel_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "FintelReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_fintel_stream_serialize(
        self,
        text_filter,
        girs,
        sub_type,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sub_type': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if sub_type is not None:
            
            _query_params.append(('sub_type', sub_type))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/fintel/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_geopol_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GeopolReportDetailsResponse:
        """Get a geopol report details

        Returns a details of a geopol report

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_geopol_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GeopolReportDetailsResponse]:
        """Get a geopol report details

        Returns a details of a geopol report

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_geopol_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a geopol report details

        Returns a details of a geopol report

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_geopol_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/geopol/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_geopol_stream(
        self,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        country: Annotated[Optional[StrictStr], Field(description="Filter result by country.")] = None,
        report_location_country: Annotated[Optional[StrictStr], Field(description="Filter result by report location.")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 100]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GeopolReportsResponseStream:
        """Get all geopol reports (stream)

        Returns a list of geopol reports (stream)

        :param sub_type: Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param country: Filter result by country.
        :type country: str
        :param report_location_country: Filter result by report location.
        :type report_location_country: str
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 100]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_stream_serialize(
            sub_type=sub_type,
            country=country,
            report_location_country=report_location_country,
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_geopol_stream_with_http_info(
        self,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        country: Annotated[Optional[StrictStr], Field(description="Filter result by country.")] = None,
        report_location_country: Annotated[Optional[StrictStr], Field(description="Filter result by report location.")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 100]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GeopolReportsResponseStream]:
        """Get all geopol reports (stream)

        Returns a list of geopol reports (stream)

        :param sub_type: Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param country: Filter result by country.
        :type country: str
        :param report_location_country: Filter result by report location.
        :type report_location_country: str
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 100]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_stream_serialize(
            sub_type=sub_type,
            country=country,
            report_location_country=report_location_country,
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_geopol_stream_without_preload_content(
        self,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        country: Annotated[Optional[StrictStr], Field(description="Filter result by country.")] = None,
        report_location_country: Annotated[Optional[StrictStr], Field(description="Filter result by report location.")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 100]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all geopol reports (stream)

        Returns a list of geopol reports (stream)

        :param sub_type: Filter result by GEOPOL subtypes. Allowed values: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param country: Filter result by country.
        :type country: str
        :param report_location_country: Filter result by report location.
        :type report_location_country: str
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 100]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_geopol_stream_serialize(
            sub_type=sub_type,
            country=country,
            report_location_country=report_location_country,
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GeopolReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_geopol_stream_serialize(
        self,
        sub_type,
        country,
        report_location_country,
        text_filter,
        girs,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sub_type': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if sub_type is not None:
            
            _query_params.append(('sub_type', sub_type))
            
        if country is not None:
            
            _query_params.append(('country', country))
            
        if report_location_country is not None:
            
            _query_params.append(('report_location_country', report_location_country))
            
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/geopol/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_info_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> InfoReportResponse:
        """Get an info report details

        Return info report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_info_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[InfoReportResponse]:
        """Get an info report details

        Return info report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_info_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get an info report details

        Return info report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_info_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/info/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_info_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> InfoReportsResponseStream:
        """Get all info reports (stream)

        Returns list of info reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_info_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[InfoReportsResponseStream]:
        """Get all info reports (stream)

        Returns list of info reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_info_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all info reports (stream)

        Returns list of info reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_info_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InfoReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_info_stream_serialize(
        self,
        text_filter,
        girs,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/info/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_malware_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MalwareReportResponse:
        """Get a malware report details

        Returns malware report based by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_malware_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MalwareReportResponse]:
        """Get a malware report details

        Returns malware report based by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_malware_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a malware report details

        Returns malware report based by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_malware_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/malware/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_malware_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        malware_family: Annotated[Optional[StrictStr], Field(description="Search malware reports by malware family")] = None,
        threat_id: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat ID")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat type")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MalwareReportsResponseStream:
        """Get all malware reports (stream)

        Returns list of malware reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param malware_family: Search malware reports by malware family
        :type malware_family: str
        :param threat_id: Search malware reports by threat ID
        :type threat_id: str
        :param threat_type: Search malware reports by threat type
        :type threat_type: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            malware_family=malware_family,
            threat_id=threat_id,
            threat_type=threat_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_malware_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        malware_family: Annotated[Optional[StrictStr], Field(description="Search malware reports by malware family")] = None,
        threat_id: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat ID")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat type")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MalwareReportsResponseStream]:
        """Get all malware reports (stream)

        Returns list of malware reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param malware_family: Search malware reports by malware family
        :type malware_family: str
        :param threat_id: Search malware reports by threat ID
        :type threat_id: str
        :param threat_type: Search malware reports by threat type
        :type threat_type: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            malware_family=malware_family,
            threat_id=threat_id,
            threat_type=threat_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_malware_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        malware_family: Annotated[Optional[StrictStr], Field(description="Search malware reports by malware family")] = None,
        threat_id: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat ID")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search malware reports by threat type")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all malware reports (stream)

        Returns list of malware reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param malware_family: Search malware reports by malware family
        :type malware_family: str
        :param threat_id: Search malware reports by threat ID
        :type threat_id: str
        :param threat_type: Search malware reports by threat type
        :type threat_type: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_malware_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            malware_family=malware_family,
            threat_id=threat_id,
            threat_type=threat_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MalwareReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_malware_stream_serialize(
        self,
        text_filter,
        girs,
        malware_family,
        threat_id,
        threat_type,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if malware_family is not None:
            
            _query_params.append(('malware_family', malware_family))
            
        if threat_id is not None:
            
            _query_params.append(('threat_id', threat_id))
            
        if threat_type is not None:
            
            _query_params.append(('threat_type', threat_type))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/malware/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_spot_id(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SpotReportResponse:
        """Get a spot report details

        Returns spot report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_spot_id_with_http_info(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SpotReportResponse]:
        """Get a spot report details

        Returns spot report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_spot_id_without_preload_content(
        self,
        id: StrictStr,
        include_inline_images: Annotated[Optional[StrictBool], Field(description="Inline images")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a spot report details

        Returns spot report by ID

        :param id: (required)
        :type id: str
        :param include_inline_images: Inline images
        :type include_inline_images: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_id_serialize(
            id=id,
            include_inline_images=include_inline_images,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_spot_id_serialize(
        self,
        id,
        include_inline_images,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if include_inline_images is not None:
            
            _query_params.append(('include_inline_images', include_inline_images))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/spot/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_spot_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SpotReportsResponseStream:
        """Get all spot reports (stream)

        Returns list of spot reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_spot_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SpotReportsResponseStream]:
        """Get all spot reports (stream)

        Returns list of spot reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_spot_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all spot reports (stream)

        Returns list of spot reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_spot_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SpotReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_spot_stream_serialize(
        self,
        text_filter,
        girs,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/spot/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_stream(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ReportResponseStream:
        """Get all reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param type: Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report
        :type type: List[str]
        :param sub_type: If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            type=type,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_stream_with_http_info(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ReportResponseStream]:
        """Get all reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param type: Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report
        :type type: List[str]
        :param sub_type: If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            type=type,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_stream_without_preload_content(
        self,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report")] = None,
        sub_type: Annotated[Optional[List[StrictStr]], Field(description="If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all reports (stream)

        Returns list of reports (stream)

        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), my_girs or company_pirs. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param type: Filter result by type of report (supports multiple). Allowed values: fintel, info_report, breach_alert, spot_report, vulnerability_report, malware_report, geopol_report, situation_report, news_report
        :type type: List[str]
        :param sub_type: If using filter `report_type=fintel` or `report_type=geopol_report`, you can then further filter result by subtypes (supports multiple). Allowed values for fintel: actor_profile, intelligence_bulletin, service_profile, underground_perspective, underground_pulse, whitepaper, threat_brief, breach_report, intelligence_summary, malware_campaign, fintel_blog, for geopol: spot_report, intelligence_bulletin, intelligence_summary, tension_point_profile, threat_brief, significant_activity_report, intelligence_estimate, adversary_profile
        :type sub_type: List[str]
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_stream_serialize(
            text_filter=text_filter,
            girs=girs,
            type=type,
            sub_type=sub_type,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ReportResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_stream_serialize(
        self,
        text_filter,
        girs,
        type,
        sub_type,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'type': 'csv',
            'sub_type': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if type is not None:
            
            _query_params.append(('type', type))
            
        if sub_type is not None:
            
            _query_params.append(('sub_type', sub_type))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_vulnerability_id(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VulnerabilitiesReportDetailsResponse:
        """Get a vulnerability report details

        Returns a details of a vulnerabilities report

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_vulnerability_id_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VulnerabilitiesReportDetailsResponse]:
        """Get a vulnerability report details

        Returns a details of a vulnerabilities report

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_vulnerability_id_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get a vulnerability report details

        Returns a details of a vulnerabilities report

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportDetailsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_vulnerability_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/vulnerability/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_reports_vulnerability_stream(
        self,
        status: Annotated[Optional[VulnerabilityStatus], Field(description="Vulnerabilities status type")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        risk_level: Annotated[Optional[List[RiskLevel]], Field(description="Search reports in a given risk level")] = None,
        patch_status: Annotated[Optional[List[PatchStatus]], Field(description="Search reports with given patch status.")] = None,
        interest_level: Annotated[Optional[List[InterestLevel]], Field(description="Search reports with given interest level.")] = None,
        activity_location: Annotated[Optional[List[ActivityLocation]], Field(description="Search reports with given activity location.")] = None,
        exploit_status: Annotated[Optional[List[ExploitStatus]], Field(description="Search reports with given exploit status.")] = None,
        cve_type: Annotated[Optional[StrictStr], Field(description="Search reports with given cve type.")] = None,
        cve_name: Annotated[Optional[StrictStr], Field(description="Search reports with given cve name.")] = None,
        vendor_name: Annotated[Optional[StrictStr], Field(description="Search reports with given vendor name.")] = None,
        product_name: Annotated[Optional[StrictStr], Field(description="Search reports with given product name.")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VulnerabilitiesReportsResponseStream:
        """Get all vulnerabilities reports (stream)

        Returns list of vulnerabilities reports (stream)

        :param status: Vulnerabilities status type
        :type status: VulnerabilityStatus
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param risk_level: Search reports in a given risk level
        :type risk_level: List[RiskLevel]
        :param patch_status: Search reports with given patch status.
        :type patch_status: List[PatchStatus]
        :param interest_level: Search reports with given interest level.
        :type interest_level: List[InterestLevel]
        :param activity_location: Search reports with given activity location.
        :type activity_location: List[ActivityLocation]
        :param exploit_status: Search reports with given exploit status.
        :type exploit_status: List[ExploitStatus]
        :param cve_type: Search reports with given cve type.
        :type cve_type: str
        :param cve_name: Search reports with given cve name.
        :type cve_name: str
        :param vendor_name: Search reports with given vendor name.
        :type vendor_name: str
        :param product_name: Search reports with given product name.
        :type product_name: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_stream_serialize(
            status=status,
            text_filter=text_filter,
            girs=girs,
            risk_level=risk_level,
            patch_status=patch_status,
            interest_level=interest_level,
            activity_location=activity_location,
            exploit_status=exploit_status,
            cve_type=cve_type,
            cve_name=cve_name,
            vendor_name=vendor_name,
            product_name=product_name,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_reports_vulnerability_stream_with_http_info(
        self,
        status: Annotated[Optional[VulnerabilityStatus], Field(description="Vulnerabilities status type")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        risk_level: Annotated[Optional[List[RiskLevel]], Field(description="Search reports in a given risk level")] = None,
        patch_status: Annotated[Optional[List[PatchStatus]], Field(description="Search reports with given patch status.")] = None,
        interest_level: Annotated[Optional[List[InterestLevel]], Field(description="Search reports with given interest level.")] = None,
        activity_location: Annotated[Optional[List[ActivityLocation]], Field(description="Search reports with given activity location.")] = None,
        exploit_status: Annotated[Optional[List[ExploitStatus]], Field(description="Search reports with given exploit status.")] = None,
        cve_type: Annotated[Optional[StrictStr], Field(description="Search reports with given cve type.")] = None,
        cve_name: Annotated[Optional[StrictStr], Field(description="Search reports with given cve name.")] = None,
        vendor_name: Annotated[Optional[StrictStr], Field(description="Search reports with given vendor name.")] = None,
        product_name: Annotated[Optional[StrictStr], Field(description="Search reports with given product name.")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VulnerabilitiesReportsResponseStream]:
        """Get all vulnerabilities reports (stream)

        Returns list of vulnerabilities reports (stream)

        :param status: Vulnerabilities status type
        :type status: VulnerabilityStatus
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param risk_level: Search reports in a given risk level
        :type risk_level: List[RiskLevel]
        :param patch_status: Search reports with given patch status.
        :type patch_status: List[PatchStatus]
        :param interest_level: Search reports with given interest level.
        :type interest_level: List[InterestLevel]
        :param activity_location: Search reports with given activity location.
        :type activity_location: List[ActivityLocation]
        :param exploit_status: Search reports with given exploit status.
        :type exploit_status: List[ExploitStatus]
        :param cve_type: Search reports with given cve type.
        :type cve_type: str
        :param cve_name: Search reports with given cve name.
        :type cve_name: str
        :param vendor_name: Search reports with given vendor name.
        :type vendor_name: str
        :param product_name: Search reports with given product name.
        :type product_name: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_stream_serialize(
            status=status,
            text_filter=text_filter,
            girs=girs,
            risk_level=risk_level,
            patch_status=patch_status,
            interest_level=interest_level,
            activity_location=activity_location,
            exploit_status=exploit_status,
            cve_type=cve_type,
            cve_name=cve_name,
            vendor_name=vendor_name,
            product_name=product_name,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_reports_vulnerability_stream_without_preload_content(
        self,
        status: Annotated[Optional[VulnerabilityStatus], Field(description="Vulnerabilities status type")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Apply text filter to search reports based on a keyword")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        risk_level: Annotated[Optional[List[RiskLevel]], Field(description="Search reports in a given risk level")] = None,
        patch_status: Annotated[Optional[List[PatchStatus]], Field(description="Search reports with given patch status.")] = None,
        interest_level: Annotated[Optional[List[InterestLevel]], Field(description="Search reports with given interest level.")] = None,
        activity_location: Annotated[Optional[List[ActivityLocation]], Field(description="Search reports with given activity location.")] = None,
        exploit_status: Annotated[Optional[List[ExploitStatus]], Field(description="Search reports with given exploit status.")] = None,
        cve_type: Annotated[Optional[StrictStr], Field(description="Search reports with given cve type.")] = None,
        cve_name: Annotated[Optional[StrictStr], Field(description="Search reports with given cve name.")] = None,
        vendor_name: Annotated[Optional[StrictStr], Field(description="Search reports with given vendor name.")] = None,
        product_name: Annotated[Optional[StrictStr], Field(description="Search reports with given product name.")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="UNIX timestamp(in milliseconds)")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Range is: [1, 1000]")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all vulnerabilities reports (stream)

        Returns list of vulnerabilities reports (stream)

        :param status: Vulnerabilities status type
        :type status: VulnerabilityStatus
        :param text_filter: Apply text filter to search reports based on a keyword
        :type text_filter: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param risk_level: Search reports in a given risk level
        :type risk_level: List[RiskLevel]
        :param patch_status: Search reports with given patch status.
        :type patch_status: List[PatchStatus]
        :param interest_level: Search reports with given interest level.
        :type interest_level: List[InterestLevel]
        :param activity_location: Search reports with given activity location.
        :type activity_location: List[ActivityLocation]
        :param exploit_status: Search reports with given exploit status.
        :type exploit_status: List[ExploitStatus]
        :param cve_type: Search reports with given cve type.
        :type cve_type: str
        :param cve_name: Search reports with given cve name.
        :type cve_name: str
        :param vendor_name: Search reports with given vendor name.
        :type vendor_name: str
        :param product_name: Search reports with given product name.
        :type product_name: str
        :param var_from: UNIX timestamp(in milliseconds)
        :type var_from: int
        :param until: UNIX timestamp(in milliseconds)
        :type until: int
        :param size: Range is: [1, 1000]
        :type size: int
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_reports_vulnerability_stream_serialize(
            status=status,
            text_filter=text_filter,
            girs=girs,
            risk_level=risk_level,
            patch_status=patch_status,
            interest_level=interest_level,
            activity_location=activity_location,
            exploit_status=exploit_status,
            cve_type=cve_type,
            cve_name=cve_name,
            vendor_name=vendor_name,
            product_name=product_name,
            var_from=var_from,
            until=until,
            size=size,
            cursor=cursor,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VulnerabilitiesReportsResponseStream",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_reports_vulnerability_stream_serialize(
        self,
        status,
        text_filter,
        girs,
        risk_level,
        patch_status,
        interest_level,
        activity_location,
        exploit_status,
        cve_type,
        cve_name,
        vendor_name,
        product_name,
        var_from,
        until,
        size,
        cursor,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'risk_level': 'multi',
            'patch_status': 'multi',
            'interest_level': 'multi',
            'activity_location': 'multi',
            'exploit_status': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if status is not None:
            
            _query_params.append(('status', status.value))
            
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if risk_level is not None:
            
            _query_params.append(('risk_level', risk_level))
            
        if patch_status is not None:
            
            _query_params.append(('patch_status', patch_status))
            
        if interest_level is not None:
            
            _query_params.append(('interest_level', interest_level))
            
        if activity_location is not None:
            
            _query_params.append(('activity_location', activity_location))
            
        if exploit_status is not None:
            
            _query_params.append(('exploit_status', exploit_status))
            
        if cve_type is not None:
            
            _query_params.append(('cve_type', cve_type))
            
        if cve_name is not None:
            
            _query_params.append(('cve_name', cve_name))
            
        if vendor_name is not None:
            
            _query_params.append(('vendor_name', vendor_name))
            
        if product_name is not None:
            
            _query_params.append(('product_name', product_name))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/intel-report/v1/reports/vulnerability/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


